@@ -17,7 +17,7 @@ for instrument in ["hst_up"]:
 
     print()
 
-    imaging = simulate_util.load_test_imaging(
+    imaging = instrument_util.load_test_imaging(
         data_name="lens_sie__source_smooth", instrument=instrument, psf_shape_2d=(3, 3)
     )
     mask = al.Mask.circular_annular(
